@@ -294,7 +294,15 @@ class System(object):
 		if s.startswith("ARM-Versatile"):
 			return ("ARM", s)
 
-		v, m = s.split(" ", 1)
+		try:
+			v, m = s.split(" ", 1)
+		except ValueError:
+			if s.startswith("BCM"):
+				v = "Broadcom"
+				m = s
+			else:
+				v = None
+				m = s
 
 		return v, m
 
@@ -358,7 +366,12 @@ class System(object):
 			if mountpoint == "/":
 				# Cut off /dev
 				dev = dev[5:]
-				# Cut off all digits at end of string
+
+				# Handle raids and MMC cards like (mmcblk0p3).
+				if dev[-2] == "p":
+					return dev[:-2]
+
+				# Otherwise cut off all digits at end of string
 				while dev[-1] in string.digits:
 					dev = dev[:-1]
 
